@@ -660,12 +660,31 @@ struct option_t MuttVars[] = {
   ** affect the generation of Message-IDs, and it will not lead to the 
   ** cut-off of first-level domains.
   */
+  { "hide_limited",	DT_BOOL, R_RESORT|R_INDEX, OPTHIDELIMITED, 0 },
+  /*
+  ** .pp
+  ** When set, mutt will not show the presence of missing messages in the
+  ** thread tree.
+  */
   { "hide_missing",	DT_BOOL, R_RESORT|R_INDEX, OPTHIDEMISSING, 1 },
   /*
   ** .pp
-  ** When set, mutt will not indicate the presence of missing messages
-  ** whose ancestors neither have siblings nor are in the current mailbox,
-  ** in the thread tree.
+  ** When set, mutt will not show the presence of messages that are hidden
+  ** by limiting, in the thread tree.
+  */
+  { "hide_top_limited",	DT_BOOL, R_RESORT|R_INDEX, OPTHIDETOPLIMITED, 0 },
+  /*
+  ** .pp
+  ** When set, mutt will not show the presence of missing messages at the
+  ** top of threads in the thread tree.  Note that when $$hide_limited is
+  ** set, this option will have no effect.
+  */
+  { "hide_top_missing",	DT_BOOL, R_RESORT|R_INDEX, OPTHIDETOPMISSING, 1 },
+  /*
+  ** .pp
+  ** When set, mutt will not show the presence of messages that are hidden
+  ** by limiting, at the top of threads in the thread tree.Note that when
+  ** $$hide_missing is set, this option will have no effect.
   */
   { "history",		DT_NUM,	 R_NONE, UL &HistSize, 10 },
   /*
@@ -851,7 +870,9 @@ struct option_t MuttVars[] = {
   ** .dt %F .dd author name, or recipient name if the message is from you
   ** .dt %i .dd message-id of the current message
   ** .dt %l .dd number of lines in the message
-  ** .dt %L .dd list-from function
+  ** .dt %L .dd If an address in the To or CC header field matches an address
+  **            defined by the users ``lists'' command, this displays
+  **            "To <list-name>", otherwise the same as %F.
   ** .dt %m .dd total number of message in the mailbox
   ** .dt %M .dd number of hidden messages if the thread is collapsed.
   ** .dt %N .dd message score
@@ -1483,7 +1504,7 @@ struct option_t MuttVars[] = {
   ** prefix'' operator.  If this variable is unset, when piping a list of
   ** tagged messages Mutt will concatenate the messages and will pipe them
   ** as a single folder.  When set, Mutt will pipe the messages one by one.
-  ** In both cases the the messages are piped in the current sorted order,
+  ** In both cases the messages are piped in the current sorted order,
   ** and the ``$$pipe_sep'' separator is added after each message.
   */
   { "pipe_decode",	DT_BOOL, R_NONE, OPTPIPEDECODE, 0 },
